#ifndef RESUME_H
#define RESUME_H

int do_resume(int argc, char *argv[]);
int resume(const char *resume_file, unsigned long long resume_offset);

#endif /* RESUME_H */
